@@ -8,9 +8,9 @@ import uuid
 
 import torch
 
-# from torch.distributed.elastic.multiprocessing import Std
-# from torch.distributed.elastic.rendezvous.utils import _parse_rendezvous_config
-# from torch.distributed.launcher.api import LaunchConfig
+from torch.distributed.elastic.multiprocessing import Std
+from torch.distributed.elastic.rendezvous.utils import _parse_rendezvous_config
+from torch.distributed.launcher.api import LaunchConfig
 from pyhocon import ConfigFactory, ConfigTree
 
 try:
